/*
 * JBoss, Home of Professional Open Source
 * Copyright 2015, Red Hat, Inc., and individual contributors as indicated
 * by the @authors tag.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.util.graph;

/**
 * A spanning tree visitor callback interface
 * 
 * @see Graph#dfsSpanningTree(Vertex, DFSVisitor)
 * 
 * @author Scott.Stark@jboss.org
 * @version $Revision$
 * @param <T> 
 */
public interface DFSVisitor<T>
{
   /**
    * Called by the graph traversal methods when a vertex is first visited.
    * 
    * @param g - the graph
    * @param v - the vertex being visited.
    */
   public void visit(Graph<T> g, Vertex<T> v);

   /**
    * Used dfsSpanningTree to notify the visitor of each outgoing edge to
    * an unvisited vertex.
    * 
    * @param g - the graph
    * @param v - the vertex being visited
    * @param e - the outgoing edge from v
    */
   public void visit(Graph<T> g, Vertex<T> v, Edge<T> e);
}
